AbinitParser — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# AbinitParser

The pyprocar.io.abinit` is used to parse the Abinit files

`pyprocar.io.abinit.AbinitProcar`([dirname, ...]) | This class has functions to parse the PROCAR file generated from Abinit.
`pyprocar.io.abinit.Output`([abinit_output]) | This class contains methods to parse the fermi energy, reciprocal lattice vectors and structure from the Abinit output file.
`pyprocar.io.abinit.AbinitKpoints`([filename, ...]) | This class parses the k-point information.